@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Usage: ./test.sh [--regold] [test-name] [python-version]
+# Usage: ./test.sh [--regold] [test-name] python[3]
 # Example:
 #   Run all tests:
 #     ./test.sh python3
@@ -25,7 +25,7 @@ if [ "$#" -gt 1 ]; then
 fi
 
 if [ "$#" != 1 ]; then
-  echo "Usage: '$0 [--regold] [test-name] python[23]'"
+  echo "Usage: '$0 [--regold] [test-name] python[3]'"
   exit 1
 fi
 
@@ -93,7 +93,7 @@ function check_git_diff() {
     # Set default args when first time check git diff
     yes | git difftool --extcmd icdiff > /dev/null
     git config --global icdiff.options '--cols=80'
-    export PATH=$PATH:"$(pwd)"
+    export PATH="$(pwd)":$PATH
   fi
   local tmp=/tmp/git-icdiff.output
   git icdiff $1 $2 &> $tmp
@@ -109,6 +109,7 @@ check_gold gold-recursive.txt       --recursive tests/{a,b} --cols=80
 check_gold gold-exclude.txt         --exclude-lines '^#|  pad' tests/input-4-cr.txt tests/input-4-partial-cr.txt --cols=80
 check_gold gold-dir.txt             tests/{a,b} --cols=80
 check_gold gold-12.txt              tests/input-{1,2}.txt --cols=80
+check_gold gold-12-t.txt            tests/input-{1,2}.txt --cols=80 --truncate
 check_gold gold-3.txt               tests/input-{3,3}.txt
 check_gold gold-45.txt              tests/input-{4,5}.txt --cols=80
 check_gold gold-45-95.txt           tests/input-{4,5}.txt --cols=95
@@ -143,8 +144,15 @@ check_gold gold-12-subcolors.txt    tests/input-{1,2}.txt --cols=80 --color-map=
 check_gold gold-subcolors-bad-color tests/input-{1,2}.txt --cols=80 --color-map='change:mageta,description:cyan_bold'
 check_gold gold-subcolors-bad-cat tests/input-{1,2}.txt --cols=80 --color-map='chnge:magenta,description:cyan_bold'
 check_gold gold-subcolors-bad-fmt tests/input-{1,2}.txt --cols=80 --color-map='change:magenta:gold,description:cyan_bold'
+check_gold gold-identical-on.txt tests/input-{1,1}.txt -s
 check_gold gold-bad-encoding.txt tests/input-{1,2}.txt --encoding=nonexistend_encoding
-check_git_diff gitdiff-only-newlines.txt 4e86205629~1 4e86205629
+
+if git show 4e86205629 &> /dev/null; then
+  # We're in the repo, so test git.
+  check_git_diff gitdiff-only-newlines.txt 4e86205629~1 4e86205629
+else
+  echo "Not in icdiff repo; skipping git test"
+fi
 
 # Testing pipe behavior doesn't fit well with the check_gold system
 $INVOCATION tests/input-{4,5}.txt 2>/tmp/icdiff-pipe-error-output | head -n 1
